import { BaseApiClient } from './base';
import { API_CONFIG } from '../config/api';
import type { CandidateAssets, CandidateDetails, CandidateExpenses, CandidateIncome, CandidateRedesSociais, CandidateSearchResult, CpfRevealResult, OpenCandDataAvailabilityStats, PlatformStats, RandomCandidate } from './apiModels';
import type { EnrichmentResponse, StatisticsConfig, ValueSumRequest, ValueSumResponse } from './apiStatisticsModels';

/**
 * OpenCand API client for interacting with the OpenCand platform
 */
export class OpenCandApi extends BaseApiClient {
  constructor(baseUrl: string = '') {
    super(baseUrl);
  }

  /**
   * Get platform statistics
   * GET /v1/stats
   */
  async getStats(): Promise<PlatformStats> {
    return this.get<PlatformStats>('/v1/stats');
  }

  /**
   * Get platform data stats
   * GET /v1/stats
   */
  async getDataAvailabilityStats(): Promise<OpenCandDataAvailabilityStats> {
    return this.get<OpenCandDataAvailabilityStats>('/v1/stats/data-availability');
  }

  /**
   * Search for candidates by name or other attributes
   */
  async searchCandidates(query: string): Promise<CandidateSearchResult> {
    const encodedQuery = encodeURIComponent(query);
    return this.get<CandidateSearchResult>(`/v1/candidato/search?q=${encodedQuery}`);
  }

  /**
   * Get a random candidate from the database
   */
  async getRandomCandidate(): Promise<RandomCandidate> {
    return this.get<RandomCandidate>(`/v1/candidato/random`);
  }

  /**
   * Get detailed information about a specific candidate by ID
   */
  async getCandidateById(id: string): Promise<CandidateDetails> {
    return this.get<CandidateDetails>(`/v1/candidato/${id}`);
  }

  /**
   * Get the assets of a specific candidate by ID
   */
  async getCandidateAssets(id: string): Promise<CandidateAssets> {
    return this.get<CandidateAssets>(`/v1/candidato/${id}/bens`);
  }

  /**
   * Get the social networks of a specific candidate by ID
   */
  async getCandidateRedesSociais(id: string): Promise<CandidateRedesSociais> {
    return this.get<CandidateRedesSociais>(`/v1/candidato/${id}/rede-social`);
  }

  /**
   * Get the social networks of a specific candidate by ID
   */
  async getCandidateCpf(id: string): Promise<CpfRevealResult> {
    return this.get<CpfRevealResult>(`/v1/candidato/${id}/reveal-cpf`);
  }

  /**
   * Get the expenses for a specific candidate by ID and year
   */
  async getCandidateDepesas(id: string): Promise<CandidateExpenses> {
    return this.get<CandidateExpenses>(`/v1/candidato/${id}/despesas`);
  }

  /**
   * Get the expenses for a specific candidate by ID and year
   */
  async getCandidateReceitas(id: string): Promise<CandidateIncome> {
    return this.get<CandidateIncome>(`/v1/candidato/${id}/receitas`);
  }

  /**
   * Get the configuration for statistics filters
   */
  async getStatisticsConfig(): Promise<StatisticsConfig> {
    return this.get<StatisticsConfig>(`/v1/estatistica/configuration`);
  }

  /**
   * Get the enrichment statistics for candidates
   */
  async getStatisticsEnrichment(): Promise<EnrichmentResponse[]> {
    return this.get<EnrichmentResponse[]>(`/v1/estatistica/enriquecimento`);
  }

  /**
   * Get the sum of values for a specific type and grouping
   */
  async getStatisticsValueSum(request: ValueSumRequest): Promise<ValueSumResponse> {
    return this.post<ValueSumResponse>(`/v1/estatistica/values-sum`, request);
  }
}

// Create a default instance for easy usage with proper configuration
export const openCandApi = new OpenCandApi(API_CONFIG.baseUrl);

// Export the API error for error handling
export { ApiError } from './base';
