import React, { useState, useEffect } from 'react';
import GlassCard from '../../shared/GlassCard';
import StatisticsFilters from './StatisticsFilters';
import StatisticsGraphs from './StatisticsGraphs';
import { fetchAllStatisticsData, type StatisticsData, type StatisticsRequestOptions } from './statisticsRequests';
import type { CargoFilter } from '../../api/apiStatisticsModels';

export interface FilterState {
  type: 'bem' | 'despesa' | 'receita';
  groupBy: 'candidato' | 'partido' | 'uf' | 'cargo';
  partido?: string | null;
  uf?: string | null;
  ano?: number | null;
  cargo?: CargoFilter;
}

const StatisticsPage: React.FC = () => {
  const [filters, setFilters] = useState<FilterState>({
    type: 'bem',
    groupBy: 'candidato',
  });
  const [isLoading, setIsLoading] = useState(false);
  const [error, setError] = useState<string | null>(null);
  const [statisticsData, setStatisticsData] = useState<StatisticsData | null>(null);

  // Load statistics data when component mounts or filters change
  useEffect(() => {
    const loadStatisticsData = async () => {
      try {
        setIsLoading(true);
        setError(null);
        
        const options: StatisticsRequestOptions = {
          filters: {
            partido: filters.partido,
            uf: filters.uf,
            ano: filters.ano,
            cargo: filters.cargo,
          },
        };

        const data = await fetchAllStatisticsData(options);
        setStatisticsData(data);
      } catch (err) {
        setError('Erro ao carregar dados estatísticos');
        console.error('Error loading statistics data:', err);
      } finally {
        setIsLoading(false);
      }
    };

    loadStatisticsData();
  }, [filters]);

  const handleFiltersChange = (newFilters: FilterState) => {
    setFilters(newFilters);
  };

  return (
    <div className="p-6 pt-16 pl-16 pr-16">
      <div className="max-w-full mx-auto">
        <div className="mb-8">
          <h1 className="text-4xl md:text-6xl font-bold mb-4 text-white4">
            Estatísticas
          </h1>
          <p className="text-white/70 text-lg">
            Análise de dados e estatísticas dos candidatos e partidos brasileiros
          </p>
          <div className="w-32 h-1 bg-gradient-to-r from-indigo-400 to-purple-400 mx-auto mt-6 rounded-full"></div>
        </div>

        <div className="flex gap-6 ">
          {/* Left Sidebar - Filters (20% width) */}
          <div className="w-1/5 min-w-[300px] h-[calc(100vh-12rem)]">
            <GlassCard 
              fullHeight 
              className="overflow-y-auto"
            >
              <StatisticsFilters
                filters={filters}
                onFiltersChange={handleFiltersChange}
                isLoading={isLoading}
              />
            </GlassCard>
          </div>

          {/* Right Content - Graphs (80% width) */}
          <div className="flex-1 overflow-auto">
            <StatisticsGraphs
                isLoading={isLoading}
                error={error}
                statisticsData={statisticsData}
              />
          </div>
        </div>
      </div>
    </div>
  );
};

export default StatisticsPage;
